@@ -2,9 +2,12 @@ package Text::VisualWidth::PP;
 use strict;
 use warnings;
 use 5.008001;
-our $VERSION = '0.02';
+use parent qw(Exporter);
+our $VERSION = '0.03';
 use Unicode::EastAsianWidth;
 
+our @EXPORT_OK = qw(vwidth vtrim);
+
 our $EastAsian = $Unicode::EastAsianWidth::EastAsian;
 
 sub InVWPP1Fullwidth() {
@@ -25,6 +28,9 @@ sub InVWPP0Halfwidth() {
     InEastAsianAmbiguous()
 }
 
+sub vwidth { width(@_) }
+sub vtrim  {  trim(@_) }
+
 sub width {
     my $str = shift;
 
@@ -83,6 +89,11 @@ Text::VisualWidth::PP - trimming text by the number of the column s of terminals
     Text::VisualWidth::PP::width("あいうえおaiu"); # => 13
     Text::VisualWidth::PP::trim("あいうえおaiu", 7); # => "あいう"
 
+    # with exporter
+    use Text::VisualWidth::PP qw(vwidth vtrim);
+    vwidth("あいうえおaiu"); # => 13
+    vtrim("あいうえおaiu", 7); # => "あいう"
+
 =head1 DESCRIPTION
 
 This module provides functions to treat half-width and full-width characters and display correct size of text in one line on terminals and mobile phones. You can know the visual width of any text and truncate text by the visual width. Now this module support flagged UTF-8 and tested only with Japanese.  
